@@ -7,7 +7,7 @@ from preacher.core.datetime import ISO8601
 from preacher.core.datetime import StrftimeFormat
 from .util.type import ensure_optional_str
 
-TIMEDELTA_PATTERN = re.compile(r'([+\-]?\d+)\s*(day|hour|minute|second)s?')
+TIMEDELTA_PATTERN = re.compile(r"([+\-]?\d+)\s*(day|hour|minute|second)s?")
 
 
 def compile_datetime_format(obj: object) -> DatetimeFormat:
@@ -18,6 +18,6 @@ def compile_datetime_format(obj: object) -> DatetimeFormat:
         CompilationError: When compilation fails.
     """
     format_string = ensure_optional_str(obj)
-    if format_string is None or format_string.lower() == 'iso8601':
+    if format_string is None or format_string.lower() == "iso8601":
         return ISO8601
     return StrftimeFormat(format_string)
