@@ -3,4 +3,4 @@
 from .extraction import ExtractionCompiler
 from .factory import create_extraction_compiler
 
-__all__ = ['ExtractionCompiler', 'create_extraction_compiler']
+__all__ = ["ExtractionCompiler", "create_extraction_compiler"]
