@@ -1,8 +1,10 @@
+from preacher.core.scheduling.factory import create_scheduler
 from preacher.core.scheduling.listener import Listener, MergingListener
 from preacher.core.scheduling.scenario_scheduler import ScenarioScheduler
 
 __all__ = [
-    'ScenarioScheduler',
-    'Listener',
-    'MergingListener',
+    "ScenarioScheduler",
+    "Listener",
+    "MergingListener",
+    "create_scheduler",
 ]
