@@ -2,4 +2,4 @@
 
 
 def to_message(error: Exception) -> str:
-    return f'{error.__class__.__name__}: {error}'
+    return f"{error.__class__.__name__}: {error}"
