@@ -3,4 +3,4 @@ Value interpretation.
 """
 from .value import Value, ValueContext
 
-__all__ = ('Value', 'ValueContext')
+__all__ = ("Value", "ValueContext")
