@@ -3,7 +3,7 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Generic, Optional, TypeVar, Type
 
-T = TypeVar('T')
+T = TypeVar("T")
 
 
 @dataclass(frozen=True)
@@ -12,12 +12,11 @@ class ValueContext:
 
 
 class Value(ABC, Generic[T]):
-
     @property
     @abstractmethod
     def type(self) -> Type[T]:
-        raise NotImplementedError()
+        ...  # pragma: no cover
 
     @abstractmethod
     def resolve(self, context: Optional[ValueContext] = None) -> T:
-        raise NotImplementedError()
+        ...  # pragma: no cover
