@@ -1,6 +1,6 @@
 from pluggy.hooks import HookimplMarker
 
-__all__ = ['hookimpl']
+__all__ = ["hookimpl"]
 
-hookimpl = HookimplMarker('preacher')
+hookimpl = HookimplMarker("preacher")
 """Marker to be imported and used in plugins (and for own implementations)"""
