@@ -1,9 +1,10 @@
 from pluggy.hooks import HookspecMarker
+from yaml import Loader
 
 from preacher.compilation.extraction import ExtractionCompiler
 from preacher.compilation.verification.matcher import MatcherFactoryCompiler
 
-hookspec = HookspecMarker('preacher')
+hookspec = HookspecMarker("preacher")
 
 
 @hookspec
@@ -24,3 +25,13 @@ def preacher_add_extractions(compiler: ExtractionCompiler) -> None:
     Args:
         compiler: A compiler to modify.
     """
+
+
+@hookspec
+def preacher_modify_yaml_loader(loader: Loader) -> None:
+    """
+    Modify a YAML loader.
+
+    Args:
+        loader: A loader to be modified.
+    """
